@@ -1,21 +1,32 @@
 # -*- coding: utf-8 -*-
-from Products.CMFPlone.Portal import PloneSite
+from logging import getLogger
+from plone.registry.interfaces import IRegistry
+from Products.CMFPlone import PloneMessageFactory as _
 from Products.CMFPlone.events import SiteManagerCreatedEvent
 from Products.CMFPlone.interfaces import INonInstallable
+from Products.CMFPlone.Portal import PloneSite
 from Products.GenericSetup.tool import SetupTool
-from plone.registry.interfaces import IRegistry
+from Products.statusmessages.interfaces import IStatusMessage
 from zope.component import queryUtility
+from zope.component.hooks import setSite
 from zope.event import notify
 from zope.interface import implementer
-from zope.site.hooks import setSite
 
 _TOOL_ID = 'portal_setup'
 _DEFAULT_PROFILE = 'Products.CMFPlone:plone'
+_TYPES_PROFILE = 'plone.app.contenttypes:default'
 _CONTENT_PROFILE = 'plone.app.contenttypes:plone-content'
 
 # A little hint for PloneTestCase
 _IMREALLYPLONE5 = True
 
+# Marker hints for code that needs to know the major Plone version
+# Works the same way than zcml condition hints so it contains the current and the
+# last ones
+PLONE52MARKER = True
+
+logger = getLogger('Plone')
+
 
 @implementer(INonInstallable)
 class NonInstallable(object):
@@ -45,7 +56,6 @@ class NonInstallable(object):
             'plone.app.dexterity',
             'plone.app.discussion',
             'plone.app.event',
-            'plone.app.folder',
             'plone.app.imaging',
             'plone.app.intid',
             'plone.app.linkintegrity',
@@ -100,7 +110,6 @@ class NonInstallable(object):
                 u'plone.app.dexterity:default',
                 u'plone.app.discussion:default',
                 u'plone.app.event:default',
-                u'plone.app.folder:default',
                 u'plone.app.imaging:default',
                 u'plone.app.linkintegrity:default',
                 u'plone.app.registry:default',
@@ -152,9 +161,11 @@ def addPloneSite(context, site_id, title='Plone site', description='',
     reg['plone.default_language'] = default_language
     reg['plone.available_languages'] = [default_language]
 
-    if setup_content:
-        setup_tool.runAllImportStepsFromProfile(
-            'profile-%s' % content_profile_id)
+    # Install default content types profile if user do not select "example content"
+    # during site creation.
+    content_types_profile = content_profile_id if setup_content else _TYPES_PROFILE
+
+    setup_tool.runAllImportStepsFromProfile('profile-{0}'.format(content_types_profile))
 
     props = dict(
         title=title,
@@ -165,8 +176,23 @@ def addPloneSite(context, site_id, title='Plone site', description='',
     site.manage_changeProperties(**props)
 
     for extension_id in extension_ids:
-        setup_tool.runAllImportStepsFromProfile(
-            'profile-%s' % extension_id)
+        try:
+            setup_tool.runAllImportStepsFromProfile(
+                'profile-%s' % extension_id)
+        except Exception as msg:
+            IStatusMessage(request).add(_(
+                'Could not install ${profile_id}: ${error_msg}! '
+                'Please try to install it manually using the "Addons" '
+                'controlpanel and report any issues to the '
+                'addon maintainers.',
+                mapping={
+                    'profile_id': extension_id,
+                    'error_msg': msg.args,
+                }),
+                type='error')
+            logger.exception(
+                'Error while installing addon {}. '
+                'See traceback below for details.'.format(extension_id))
 
     if snapshot is True:
         setup_tool.createSnapshot('initial_configuration')
