@@ -1,8 +1,12 @@
+# -*- coding: utf-8 -*-
+import six
+
+
 def _unicode_replace(structure):
-    if isinstance(structure, str):
+    if isinstance(structure, six.binary_type):
         text = structure.decode('utf-8', 'replace')
     else:
-        text = unicode(structure)
+        text = six.text_type(structure)
     return text
 
 
